@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.016-7-g0232279
+package Dist::Zilla::Plugin::Test::CheckBreaks; # git description: v0.017-7-gb9ae6df
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Generate a test that shows what modules you are breaking
 # KEYWORDS: distribution prerequisites upstream dependencies modules conflicts breaks breakages metadata
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 use Moose;
 with (
@@ -165,7 +165,8 @@ sub _test_count {
     my $test_count = $self->conflicts_module;
     ++$test_count if not $test_count;
 
-    ++$test_count if not keys %{ $self->_x_breaks_data };
+    # ...and one for the x_breaks section, even if empty
+    ++$test_count;
     return $test_count;
 }
 
@@ -218,7 +219,7 @@ __PACKAGE__->meta->make_immutable;
 #pod L<[Conflicts]|Dist::Zilla::Plugin::Conflicts> to be used in your distribution;
 #pod this is only a feature added for backwards compatibility.
 #pod
-#pod This option can be used more than once.
+#pod This option can be used more than once starting with version 0.017.
 #pod
 #pod =head2 C<no_forced_deps>
 #pod
@@ -271,7 +272,7 @@ Dist::Zilla::Plugin::Test::CheckBreaks - Generate a test that shows what modules
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -318,7 +319,7 @@ There is no error if the module does not exist. This test does not require
 L<[Conflicts]|Dist::Zilla::Plugin::Conflicts> to be used in your distribution;
 this is only a feature added for backwards compatibility.
 
-This option can be used more than once.
+This option can be used more than once starting with version 0.017.
 
 =head2 C<no_forced_deps>
 
@@ -434,24 +435,30 @@ CHECK_CONFLICTS
 {{
     if (keys %$breaks)
     {
-        my $dumper = Data::Dumper->new([ $breaks ], [ 'breaks' ]);
-        $dumper->Sortkeys(1);
-        $dumper->Indent(1);
-        $dumper->Useqq(1);
+        my $dumped = Data::Dumper->new([ $breaks ], [ 'breaks' ])
+            ->Sortkeys(1)
+            ->Indent(1)
+            ->Useqq(1)
+            ->Dump;
         my $dist_name = $dist->name;
-        ($no_forced_deps ? 'SKIP: {' . "\n" : '')
-        . '# this data duplicates x_breaks in META.json' . "\n"
-        . 'my ' . $dumper->Dump
 
-        . "\n" . join("\n", $no_forced_deps
-            ?
-                ("skip 'This information-only test requires CPAN::Meta::Requirements', 0\n    if not eval 'require CPAN::Meta::Requirements';",
-                 "skip 'This information-only test requires CPAN::Meta::Check $cmc_prereq', 0\n    if not eval 'require CPAN::Meta::Check; CPAN::Meta::Check->VERSION($cmc_prereq)';")
-            :
-                ('use CPAN::Meta::Requirements;', "use CPAN::Meta::Check $cmc_prereq;"))
-        . "\n\n"
+        my $breaks_content = <<CHECK_BREAKS_header;
+# this data duplicates x_breaks in META.json
+my $dumped
+CHECK_BREAKS_header
 
-    . <<'CHECK_BREAKS_1b'
+        $breaks_content .= $no_forced_deps ? <<CHECK_BREAKS_prereq_nodeps
+skip 'This information-only test requires CPAN::Meta::Requirements', 1
+    if not eval 'require CPAN::Meta::Requirements';
+skip 'This information-only test requires CPAN::Meta::Check $cmc_prereq', 1
+    if not eval 'require CPAN::Meta::Check; CPAN::Meta::Check->VERSION($cmc_prereq)';
+CHECK_BREAKS_prereq_nodeps
+            : <<CHECK_BREAKS_prereq_deps;
+use CPAN::Meta::Requirements;
+use CPAN::Meta::Check $cmc_prereq;
+CHECK_BREAKS_prereq_deps
+
+        $breaks_content .= "\n" . <<'CHECK_BREAKS_checks';
 my $reqs = CPAN::Meta::Requirements->new;
 $reqs->add_string_requirement($_, $breaks->{$_}) foreach keys %$breaks;
 
@@ -459,14 +466,22 @@ our $result = CPAN::Meta::Check::check_requirements($reqs, 'conflicts');
 
 if (my @breaks = grep { defined $result->{$_} } keys %$result)
 {
-CHECK_BREAKS_1b
-    . "    diag 'Breakages found with $dist_name:';\n"
-    . <<'CHECK_BREAKS_2'
+CHECK_BREAKS_checks
+
+        $breaks_content .= "    diag 'Breakages found with $dist_name:';\n"
+            . <<'CHECK_BREAKS_diag';
     diag "$result->{$_}" for sort @breaks;
     diag "\n", 'You should now update these modules!';
 }
-CHECK_BREAKS_2
-        . ($no_forced_deps ? '}' . "\n" : '')
+
+pass 'checked x_breaks data';
+CHECK_BREAKS_diag
+
+        if ($no_forced_deps) {
+            $breaks_content =~ s/^(?=.)/    /mg;
+            $breaks_content = 'SKIP: {' . "\n" . $breaks_content . '}';
+        }
+        $breaks_content;
     }
     else { q{pass 'no x_breaks data to check';} . "\n" }
 }}
